/**
 * Copyright (c) 2014-present, Facebook, Inc. All rights reserved.
 *
 * This source code is licensed under the BSD-style license found in the
 * LICENSE file in the root directory of this source tree. An additional grant
 * of patent rights can be found in the PATENTS file in the same directory.
 *
 */

'use strict';

const fbjsConfig = require('eslint-config-fbjs');

const variableNamePattern = String.raw`\s*[a-zA-Z_$][a-zA-Z_$\d]*\s*`;
const importPattern = String.raw`^(?:var|let|const|import type)\s+` +
  '{?' + variableNamePattern + '(?:,' + variableNamePattern + ')*}?' +
  String.raw`\s*(?:=\s*require\(|from)[a-zA-Z_+./''\s\d\-]+\)?[^;\n]*[;\n]`;
const maxLenIgnorePattern = String.raw`(^\s*it\(|${importPattern})`;

module.exports = Object.assign({}, fbjsConfig, {
  'rules': Object.assign({}, fbjsConfig.rules, {
    'array-bracket-spacing': [2, 'never'],
    'arrow-spacing': [2],
    'babel/arrow-parens': [2, 'as-needed'],
    'babel/flow-object-type': [2, 'comma'],
    'babel/func-params-comma-dangle': [2, 'always-multiline'],
    'brace-style': [2, '1tbs', {
      'allowSingleLine': true,
    }],
    'comma-dangle': [2, 'always-multiline'],
    'comma-spacing': [2],
    'comma-style': [2, 'last'],
    'computed-property-spacing': [2, 'never'],
    'eol-last': [2],
    'max-len': [2, {
      'code': 80,
      'ignoreUrls': true,
      'ignorePattern': maxLenIgnorePattern,
    }],
    'no-const-assign': [2],
    'no-extra-parens': [2, 'functions'],
    'no-irregular-whitespace': [2],
    'no-this-before-super': [2],
    'no-var': [2],
    'object-curly-spacing': [2, 'never'],
    'object-shorthand': [2],
    'prefer-arrow-callback': [2],
    'prefer-const': [2],
    'quotes': [2, 'single', {
      'avoidEscape': true,
      'allowTemplateLiterals': true,
    }],
    'semi': [2, 'always'],
    'space-before-blocks': [2],
    'space-before-function-paren': [2, 'never'],
    'space-in-parens': [2, 'never'],
  }),
});
